python-ctd
==========

Load and pre-process CTD/XBT casts as pandas DataFrames.


.. toctree::
   :maxdepth: 3

   quick_intro.ipynb
   ctd

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
